; **********************************************************************
;
;                The Cepheid Period-Luminosity Relation
;
;                             Chris Malone
;                      Dept. of Physics & Astronomy
;                       SUNY Stony Brook, NY 11790
;
;                For:  PHY515
;                Date: February 27, 2007
;
; **********************************************************************

; choose the list file
list = 'f1ceph.list'

; number of stars in file list
nstars = 22 

; get information from star list
read_star_list,list,nstars,id,ra,dec,mag

; read in the header file
img = readfits('lmcf1_031125_i.fits',header)

; get (x,y) information for each star, to be used in centroiding
adxy,header,ra,dec,xpos,ypos

; find stars too close to edges, there has to be a better way of doing this?
s=size(img)
img=rebin(img,s[1]/2,s[2]/2)
s=size(img)
xpos=xpos/2. & ypos=ypos/2.

; =========================================
;         to create image for report
;s=size(img)
;m=median(img)
;sx=s[1]
;sy=s[2]
;window,xsize=sx,ysize=sy
;!p.position=[0,0,1,1]
;set_xy,0,sx-1,0,sy-1
;plot,indgen(10)
;tvscl,(img>m)<(m+1000)
; include astrolib for drawing circles to give rough idea of where
; stars are located
;astrolib
;colors=fsc_color(['blue','red'],indgen(2)+1)
;tvcircle,3,xpos,ypos,color=colors[0]
;tvcircle,10,xpos,ypos,color=colors[1]
;tvlist,img
;write_png,'samp.png',tvrd()

; ======================
; clean up the bad stars
too_close = 10

l = where(xpos lt too_close)
r = where(s[1] - xpos lt too_close)
t = where(s[2] - ypos lt too_close)
b = where(ypos lt too_close)

bad=[l,r,t,b]
remove,where(bad lt 0), bad

; remove those stars from all data
remove,bad,id,ra,dec,mag,xpos,ypos

; find stars that are too close to one another, again must be easier
; way of doing this
s2=size(xpos)
bad2=-1

; cut down on looping only do pairs that havnt been looked at before
for i = 0,s2[1]-2 do begin
; calculate distance from given star
    dist=sqrt((xpos[i+1:*]-xpos[i])^2 + (ypos[i+1:*]-ypos[i])^2)

; find the index of the star that is too close to the i'th star
    ind=where(dist lt too_close,count) + i + 1

; store their indices in an array to be used in remove
    if count ne 0 then begin
        bad2=[bad2,i,ind]
    endif
endfor

bad2=bad2[where(bad2 ge 0)]
remove,bad2,id,ra,dec,mag,xpos,ypos

; ======================================================
; centroid stuff here
; use xpos and ypos as the x,y inputs of centroid
; the image file 'img' is already open, so just use that

xcen=xpos*0.
ycen=ypos*0.

CNTRD, img, xpos, ypos, xcen, ycen, 1.4

; get info from all i-band images
files=findfile('*i*.fits')

; used for total number of files
sf=size(files)

; ====================
; get rid of bad files
files=[files[1:3],files[5:(sf[1]-1)]]

; update sf
sf=size(files)

; used for total number of target stars
sim=(size(id))[1]

; create an array of structures to hold the date and intensity of all
; target stars for all the images
data = replicate({date:0.0d,intens:fltarr(sim)},sf[1])

; used in date convserion; each index corresponds to a month, i.e. 
; daysum[1] is Jan., and each element corresponds to the day number
; at the end of that month
daysum= [0,31,59,90,120,151,181,212,243,273,304,334,365]

; ===================
; loop over all files

aperrad = 2.
skyrad  = [aperrad,6.]
aperrad = [aperrad]

refsum=fltarr(sf[1])
err=refsum
errstar=fltarr(sf[1],sim)
cntstar=errstar


for k=0,sf[1]-1 do begin
    print,files[k]

    img = readfits(files[k],header)
    simg = size(img)/2
    img=rebin(img,simg[1],simg[2])

; convert date string read in from header to a 5 element vector
; containing the year, day (1 to 366), hour, min, sec
    d=date_conv(sxpar(header,'date-obs'),'V')

; find the corresponding month 
    j=max(where(daysum lt d[1]))

; 6 element date vector containing year, month (1 to 12), day (1 to
; 31), hour, min, sec
    d=[d[0],j+1,d[1]-daysum[j],d[2],d[3],d[4]]

; convert to reduced julian date
    juldate,d,jd

; ==============================
; Doing the aperature photometry

    aper,img,xcen,ycen,mags,error,sky,skyerr,1,aperrad,skyrad,/FLUX,/SILENT

    errstar[k,*]=error
    cntstar[k,*]=mags

    print,'******finished targets******'

; This file contains stars = mag1 and errors = error2, xpos = sxx,
; ypos = syy in this order 
    restore,'backgroundstars',/verbose

; This file contains background = mag2 and errors = error4, xpos =
; bx, ypos = by in this order 
    restore,'background',/verbose 

; ====================================================================
;this removes a dead point at the end of the array of background stars 
    sxx = sxx[0:16]
    syy = syy[0:16]

;s=size(img)
;m=median(img)
;sx=s[1]
;sy=s[2]
;window,xsize=sx,ysize=sy
;!p.position=[0,0,1,1]
;set_xy,0,sx-1,0,sy-1
;plot,indgen(10)
;tvscl,img<700;(img>m)<(m+1000)
; include astrolib for drawing circles to give rough idea of where
; stars are located
;astrolib
;colors=fsc_color(['blue','red'],indgen(2)+1)
;tvcircle,10,xcen,ycen,color=colors[1]
;tvcircle,10,sxx,syy,color=100;colors[0]
;tvlist,img
;write_png,'samp.png',tvrd()

; =============================================
; Repeating the photometry for background stars

    aper,img,sxx,syy,mags1,error1,sky,skyerr,1,aperrad,skyrad,/FLUX,/SILENT

    print,'******done with references******'

; the sum of the background star count and its error
    refsum[k] = TOTAL(mags1)
    err[k]    = sqrt(total(error1^2))
; Define the array that will hold all magnitude data for each night
    ratio=mags/refsum[k]
    magnitude = -2.5 *alog10(ratio) 

; =================================================================

; save data back to structure
    data[k].date=jd
    data[k].intens=magnitude
endfor

freqprob=fltarr(sim)
prob=fltarr(sim)


; =============================================
; set plot parameters 

!p.multi = [0,2,3]

window,xsize=1000,ysize=1000
filename='star.png'
colors=fsc_color(['white','black'],indgen(2)+1)

wmerr=fltarr(sim)
wmean=wmerr
period=wmerr
perror=wmerr

for i=0,sim-1 do begin
; ==============================================
; do lomb-scargle and get some error information
    print,id[i]

    scargle,data.date,data.intens[i],f,pow,jmax,fp,p,sigma
    freqprob[i]=fp
    prob[i]=p

    relvarstr=(errstar[*,i]/cntstar[*,i])^2
    relvarsum=(err/refsum)^2
    errorstar = (2.5/alog(10.))*sqrt(relvarstr+relvarsum)

; =======================================================
; calculate weighted mean and error of magnitude and plot

    avevar,data.intens[i],dave,dvar
    wmean[i]=dave
    wmerr[i]=sqrt(dvar)

    period[i] = 1./fp
    perror[i] = sigma/fp^2
print,wmean[i],wmerr[i]
print,period[i],perror[i]

; change the error for the logscale
;    perror[i] = perror[i]/(alog(10.)*period[i])
;   too big for plot

; ===================================================
; output the lightcurve with errors and power spectra

    a = max(data.intens[i])+0.2
    b = min(data.intens[i])-0.2

    align=0.5

    if i eq 3 then filename='star2.png'
    if i eq 6 then filename='star3.png'
    if i eq 9 then filename='star4.png'
    if i eq 12 then filename='star5.png'
    if i eq 15 then filename='star6.png'

    if i eq 5 then align=1
   ploterror,data.date,data.intens[i],errorstar,psym=7,xrange=[52970,52990],yrange=[b,a],ytitle=id[i],background=colors[0],color=colors[1],errcolor=colors[1],symsize=1,chars=3

    plot,f,pow,xrange=[min(f),max(f)],xstyle=1,yrange=[0,1.1*pow[jmax]],color=colors[1],chars=3
    xyouts,freqprob[i],1.01*pow[jmax],string(freqprob[i]),alignment=align,color=colors[1],chars=2
    write_png,filename,tvrd()
endfor

; ===============================================================
; plot the period vs magnitude
result=linfit(alog10(period),wmean,measure_errors=wmerr,sigma=sig,prob=probability,chisq=chsq)
print,result,sig,probability,chsq

xpl=findgen(100)/100.
ypl=result[0]+result[1]*xpl

slope=string(result[1])
slope=strmid(slope,(strpos(slope,'-')))

yint=string(result[0])
yint=strmid(yint,(strpos(yint,'7')))

eqn='y='+slope+'x + '+yint

;ploterror,alog10(period),wmean,wmerr,xrange=[0,1],xstyle=1,psym=7,hatlength=!d.x_vsize/200.,background=colors[0],color=colors[1],errcolor=colors[1],ytitle="DELTA MAG",xtitle="LOG(P) (days)",charsize=2
;oplot,xpl,ypl,color=colors[1]
;xyouts,0.5,6.0,eqn,color=colors[1],charsize=2
;write_png,'plrel.png',tvrd()

; ===============================================================
;     used to generate night to night variations of references

;colors=fsc_color(['white','black'],indgen(2)+1)
;!p.multi=0
;set_plot,'X'
;avevar,refsum,ave,var

;window,xsize=1000.,ysize=1000.
;ploterror,data.date/10000.,refsum,err,ystyle=1,yrange=[0.8*min(refsum),1.2*max(refsum)],background=colors[0],color=colors[1],errcolor=colors[1],xtitle="(JULIAN DATE)/10000",psym=3,ytitle="COUNTS"
;oplot,!x.crange,fltarr(2)+ave,color=colors[1]
;oplot,!x.crange,fltarr(2)+ave+sqrt(var),color=colors[1],linestyle=1
;oplot,!x.crange,fltarr(2)+ave-sqrt(var),color=colors[1],linestyle=1
;write_png,'err.png',tvrd()

end 
