; cmalone
pro proof_sc,npoints,period,x,y,SINE=sine,PNG=png,PS=ps,filename=filename

if N_params() eq 0 then begin
    print,''
    print,'Syntax: proof_sc,n,p,x,y,/SINE,/PNG,/PS,filename=filename'
    print,''
    print,'Description:  Plots a cosine (or sine if /SINE set) function of '
    print,'            period p using n discrete points.  The x and y '
    print,'            coordinates are saved in the arrays x and y.  Then '
    print,'            a call is made to scargle.pro to determine the power'
    print,'            spectrum which is also plotted.  Output will also '
    print,'            dumped to a file psc.png if /PNG set or with the PS'
    print,'            extension if /PS set.  Default filename=psc'
    return
endif

fname="psc"
if keyword_set(filename) then fname=filename

half=period/2.
x=randomu(seed,npoints)*half*1.5
p=fix(x mod 2)
x=x*(-1)^p

func="y=cos(x*pi/"

if keyword_set(SINE) then begin
    y=sin(x*!pi/half)
    func="y=sin(x*pi/"
endif else y=cos(x*!pi/half)

func=func+strmid(string(half),strpos(string(half),' ',/reverse_search)+1)+')'

colors=fsc_color(['white','black'],indgen(2)+1)
window,xsize=1000,ysize=1000
!p.multi=[0,1,2]

plot,x,y,psym=1,xrange=[-1.5*half,1.5*half],xstyle=1,yrange=[-1,1],ystyle=1,background=colors[0],color=colors[1]
xyouts,0,-0.5,func,color=colors[1],charsize=2,align=0.5

scargle,x,y,freq,power,jmax,freqprob,prob,sigma

plot,freq,power,background=colors[0],color=colors[1],xtitle="FREQUENCY(Hz)",ytitle="POWER",xrange=[min(freq),max(freq)],xstyle=1

if keyword_set(PS) then begin
    set_plot,'PS'
    fname=fname+'.ps'
    device,filename=fname
    plot,x,y,psym=1,xrange=[-1.5*half,1.5*half],xstyle=1,yrange=[-1,1],ystyle=1,background=colors[0],color=colors[1]
    plot,freq,power,xrange=[min(freq),max(freq)],xstyle=1
    device,/close
endif else if keyword_set(PNG) then begin
    fname=fname+'.png'
    write_png,fname,tvrd()
endif
return
end
